@@ -26,8 +26,8 @@ class CinderVolumeNegativeTests(base.ClientTestBase):
 
     @ddt.data(
         ('', (r'Size is a required parameter')),
-        ('-1', (r'Invalid volume size provided for create request')),
-        ('0', (r'Invalid input received')),
+        ('-1', (r'Invalid input for field/attribute size')),
+        ('0', (r"Invalid input for field/attribute size")),
         ('size', (r'invalid int value')),
         ('0.2', (r'invalid int value')),
         ('2 GB', (r'unrecognized arguments')),
