@@ -37,6 +37,7 @@ class Volume(volumes.Volume):
                            3.1-latest).
         :param protected: Boolean to decide whether prevents image from being
                           deleted (allowed for 3.1-latest).
+        :returns: tuple (response, body)
         """
         if self.manager.api_version >= api_versions.APIVersion("3.1"):
             visibility = 'private' if visibility is None else visibility
@@ -77,7 +78,7 @@ class VolumeManager(volumes.VolumeManager):
                volume_type=None, user_id=None,
                project_id=None, availability_zone=None,
                metadata=None, imageRef=None, scheduler_hints=None,
-               source_replica=None, multiattach=False, backup_id=None):
+               multiattach=False, backup_id=None):
         """Create a volume.
 
         :param size: Size of volume in GB
@@ -87,13 +88,12 @@ class VolumeManager(volumes.VolumeManager):
         :param name: Name of the volume
         :param description: Description of the volume
         :param volume_type: Type of volume
-        :param user_id: User id derived from context
-        :param project_id: Project id derived from context
+        :param user_id: User id derived from context (IGNORED)
+        :param project_id: Project id derived from context (IGNORED)
         :param availability_zone: Availability Zone to use
         :param metadata: Optional metadata to set on volume creation
         :param imageRef: reference to an image stored in glance
         :param source_volid: ID of source volume to clone from
-        :param source_replica: ID of source volume to clone replica
         :param scheduler_hints: (optional extension) arbitrary key-value pairs
                             specified by the client to help boot an instance
         :param multiattach: Allow the volume to be attached to more than
@@ -119,15 +119,10 @@ class VolumeManager(volumes.VolumeManager):
                            'name': name,
                            'description': description,
                            'volume_type': volume_type,
-                           'user_id': user_id,
-                           'project_id': project_id,
                            'availability_zone': availability_zone,
-                           'status': "creating",
-                           'attach_status': "detached",
                            'metadata': volume_metadata,
                            'imageRef': imageRef,
                            'source_volid': source_volid,
-                           'source_replica': source_replica,
                            'multiattach': multiattach,
                            'backup_id': backup_id
                            }}
